var foo = 1;
var bar = 2;

export { bar, foo };
